@@ -9,7 +9,8 @@ def jsiter(self_obj):
         return type_cache[type(self_obj)](self_obj)
     elif issubclass(type(self_obj),jsiter_base):
         return self_obj
-    iter(self_obj)
+    if not isinstance(self_obj, Iterable):
+        raise TypeError(f"'{type(self_obj).__name__}' object is not iterable")
 #     if type(self_obj) == str:
 #         return self_obj
     class jsiter_class(jsiter_base):
